@@ -1,5 +1,6 @@
 from django.contrib.auth import get_user_model
 from django.contrib.auth.backends import ModelBackend
+from django.core.exceptions import ImproperlyConfigured
 
 from .functions import is_guest_user
 
@@ -7,6 +8,11 @@ from .functions import is_guest_user
 class GuestBackend(ModelBackend):
     def authenticate(self, request, username=None, password=None, **kwargs):
         """Authenticate with username only."""
+        if password is not None:
+            raise ImproperlyConfigured(
+                "The GuestBackend received a password argument. This is likely a configuration error. "
+                "Please ensure that Guestbackend is the last entry in AUTHENTICATION_BACKENDS."
+            )
         UserModel = get_user_model()
 
         try:
@@ -21,7 +27,6 @@ class GuestBackend(ModelBackend):
         UserModel = get_user_model()
         try:
             user = UserModel._default_manager.get(pk=user_id)
-            # user.backend = "guest_user.backends.GuestBackend"
         except UserModel.DoesNotExist:
             return None
         return user
