@@ -1,15 +1,15 @@
-import django.dispatch
+from django.dispatch import Signal
 
-guest_created = django.dispatch.Signal()
+guest_created = Signal()
 """
-A guest account has been created for a visitor.
+A visitor accessed a view that created a guest user.
 
 :param user: The new guest user.
 :param request: The request that created the guest user.
 
 """
 
-converted = django.dispatch.Signal()
+converted = Signal()
 """
 A guest user converted to a regular registered user.
 
